from setuptools import setup

setup(
    name='urban-async',
    version='0.1.5a',
    description='An async Python API wrapper for Urban Dictionary',
    long_description='An async Python API wrapper for Urban Dictionary',
    url='https://github.com/kwugfighter/urbanasync',
    author='kwugfighter',
    author_email='isaacli430@gmail.com',
    license='MIT',
    keywords=['urban', 'async', 'urban py', 'urban dictionary'],
    classifiers=[
        'Development Status :: 3 - Alpha',

        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        'License :: OSI Approved :: MIT License',

        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6'
    ],
    packages=['urbanasync']
)